@@ -223,10 +223,7 @@ class ArgumentBase(Store):
 
         kwargs.pop("aliases", None)
         kwargs.pop("env_var", None)
-
-        if kwargs.pop("converter", None):
-            kwargs.pop("type", None)
-
+        kwargs.pop("converter", None)
         kwargs.update(action=action, nargs=nargs)
 
         return {k: v for k, v in kwargs.items() if v is not None}
@@ -460,6 +457,9 @@ class Parser(AbstractParser, Base):
             if argument.env_var in os.environ:
                 self._used_env_vars.add(argument.env_var)
 
+        if kwargs.get("default"):
+            kwargs['required'] = False
+
         return dest, parser.add_argument(*aliases, **kwargs)
 
     @staticmethod
@@ -569,8 +569,6 @@ class Parser(AbstractParser, Base):
                     default=default,
                     env_var=self.get_env_var(dest, argument),
                 )
-                if default and argument.required:
-                    argument = argument.copy(required=False)
                 dest, action = self._add_argument(
                     group_parser, argument, dest, *aliases
                 )
@@ -640,6 +638,8 @@ class Parser(AbstractParser, Base):
                     parsed_value = getattr(parsed_ns, key)
 
                 if argument is not None and argument.converter is not None:
+                    if argument.nargs and parsed_value is None:
+                        parsed_value = []
                     parsed_value = argument.converter(parsed_value)
                 setattr(target, name, parsed_value)
 
